#[api]Expand description
The main attribute macro: #[api]
Place this on an impl block. Methods annotated with #[api_handler(...)]
will have axum handler functions and a typed HTTP client generated automatically.
#[api]The main attribute macro: #[api]
Place this on an impl block. Methods annotated with #[api_handler(...)]
will have axum handler functions and a typed HTTP client generated automatically.